@@ -8,7 +8,7 @@
     async function onRender(event) {
       const {height} = event.detail.args;
       const {title} = event.detail.args;
-      const {value} = event.detail.args;
+      var {value} = event.detail.args;
       const {icon} = event.detail.args;
       const {progress} = event.detail.args;
       const {animate} = event.detail.args;
@@ -45,16 +45,18 @@
       pgb.style.backgroundColor=progressColor;
       titled.innerHTML=title;
       
-
-      if(isNaN(value)){
+      var tryNumber = Number(value)
+      if(isNaN(tryNumber)){
         vald.innerText=value;
         if(animate==true)
           animateText(vald,animateDuration);
       }
       else{
         oldVal=parseFloat(vald.innerText);
+        if (isNaN(oldVal))
+          oldVal=0
         if(animate==true)
-          animateValue(vald,oldVal,value,animateDuration,unit);
+          animateValue(vald,oldVal,tryNumber,animateDuration,unit);
         else
           vald.innerText=value  + unit;
       }
